@@ -1,21 +1,5 @@
-#!/usr/bin/env python
-"""cssutils - CSS Cascading Style Sheets library for Python
-
-    Copyright (C) 2004-2013 Christof Hoeke
-
-    cssutils is free software: you can redistribute it and/or modify
-    it under the terms of the GNU Lesser General Public License as published by
-    the Free Software Foundation, either version 3 of the License, or
-    (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU Lesser General Public License for more details.
-
-    You should have received a copy of the GNU Lesser General Public License
-    along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
+"""
+CSS Cascading Style Sheets library for Python
 
 A Python package to parse and build CSS Cascading Style Sheets. DOM only, not
 any rendering facilities!
@@ -69,19 +53,11 @@ but cssutils *should* be able to read and write as many as possible CSS
 stylesheets "in the wild" while at the same time implement the official APIs
 which are well documented. Some minor extensions are provided as well.
 
-Please visit http://cthedot.de/cssutils/ for more details.
+Please visit https://cssutils.readthedocs.io/ for more details.
 
+Example::
 
-Tested with Python 2.7.6 and 3.3.3 on Windows 8.1 64bit.
-
-
-This library may be used ``from cssutils import *`` which
-import subpackages ``css`` and ``stylesheets``, CSSParser and
-CSSSerializer classes only.
-
-Usage may be::
-
-    >>> from cssutils import *
+    >>> from cssutils import CSSParser
     >>> parser = CSSParser()
     >>> sheet = parser.parseString('a { color: red}')
 
@@ -160,6 +136,7 @@ class DOMImplementationCSS(object):
 
         warning = (
             "Deprecated, see "
+            "https://web.archive.org/web/20200701035537/"
             "https://bitbucket.org/cthedot/cssutils/issues/69#comment-30669799"
         )
         warnings.warn(warning, DeprecationWarning)
@@ -167,16 +144,18 @@ class DOMImplementationCSS(object):
 
     def createDocument(self, *args, **kwargs):
         # sometimes cssutils is picked automatically for
-        # xml.dom.getDOMImplementation, so we should provide an implementation
-        # see https://bitbucket.org/cthedot/cssutils/issues/69
+        # xml.dom.getDOMImplementation, so provide an implementation
+        # see (https://web.archive.org/web/20200701035537/
+        # https://bitbucket.org/cthedot/cssutils/issues/69)
         import xml.dom.minidom as minidom
 
         return minidom.DOMImplementation().createDocument(*args, **kwargs)
 
     def createDocumentType(self, *args, **kwargs):
         # sometimes cssutils is picked automatically for
-        # xml.dom.getDOMImplementation, so we should provide an implementation
-        # see https://bitbucket.org/cthedot/cssutils/issues/69
+        # xml.dom.getDOMImplementation, so provide an implementation
+        # see (https://web.archive.org/web/20200701035537/
+        # https://bitbucket.org/cthedot/cssutils/issues/69)
         import xml.dom.minidom as minidom
 
         return minidom.DOMImplementation().createDocumentType(*args, **kwargs)
